#include "ranges.ih"

Ranges::~Ranges()
{
    delete[] d_alphabet;
}
